Index: c/src/ChangeLog
===================================================================
--- c/src/ChangeLog	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/ChangeLog	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -1,14 +1,37 @@
+2004-03-23	Ralf Corsepius <ralf_corsepius@rtems.org>
+
+	* libchip/ide/ata.c, libchip/ide/ata_internal.h,
+	libchip/ide/ide_controller.c, libchip/ide/ide_ctrl_cfg.h,
+	libchip/ide/ide_ctrl_io.h, libchip/network/cs8900.c,
+	libchip/network/dec21140.c, libchip/network/elnk.c,
+	libchip/network/if_fxp.c, libchip/network/open_eth.c,
+	libchip/network/open_eth.h, libchip/network/sonic.c,
+	libchip/network/sonic.h, libchip/rtc/icm7170.c, libchip/rtc/icm7170.h,
+	libchip/rtc/icm7170_reg.c, libchip/rtc/icm7170_reg2.c,
+	libchip/rtc/icm7170_reg4.c, libchip/rtc/icm7170_reg8.c,
+	libchip/rtc/m48t08.c, libchip/rtc/m48t08.h, libchip/rtc/m48t08_reg.c,
+	libchip/rtc/m48t08_reg2.c, libchip/rtc/m48t08_reg4.c,
+	libchip/rtc/m48t08_reg8.c, libchip/rtc/rtc.h, libchip/serial/mc68681.c,
+	libchip/serial/mc68681.h, libchip/serial/mc68681_reg.c,
+	libchip/serial/mc68681_reg2.c, libchip/serial/mc68681_reg4.c,
+	libchip/serial/mc68681_reg8.c, libchip/serial/ns16550.c,
+	libchip/serial/ns16550_p.h, libchip/serial/serial.h,
+	libchip/serial/z85c30.c, libchip/serial/z85c30.h,
+	libchip/serial/z85c30_p.h, libchip/serial/z85c30_reg.c,
+	libchip/shmdr/addlq.c, libchip/shmdr/cnvpkt.c, libchip/shmdr/dump.c,
+	libchip/shmdr/fatal.c, libchip/shmdr/getlq.c, libchip/shmdr/init.c,
+	libchip/shmdr/initlq.c, libchip/shmdr/intr.c, libchip/shmdr/poll.c,
+	libchip/shmdr/send.c, libchip/shmdr/shm_driver.h: Convert to using c99
+	fixed-size types.
+
 2004-03-14	Chris Johns  <chrisj@rtems.org>
 
-	* cs8900.c.bsp, cs8900.h.bsp: Updated the BSP example code.
-
-	* cs8900.c, cs8900.h:
-	Changes made to support the DIMMPC. This is a pc396 target with IO port
-	support.
-	Minor formating clean up.
-	Add documentation to the header file.
-
-	* README.cs8900:
-	The CS8900 driver is documented in the cs8900.h header file.
+	* libchip/network/cs8900.c.bsp, libchip/network/cs8900.h.bsp: Updated
+	the BSP example code.
+	* libchip/network/cs8900.c, libchip/network/cs8900.h: Changes made to
+	support the DIMMPC. This is a pc386 target with IO port support. Minor
+	formating clean up. Add documentation to the header file.
+	* libchip/network/README.cs8900: The CS8900 driver is documented in the
+	cs8900.h header file.
 
 2004-03-09	Ralf Corsepius <corsepiu@faw.uni-ulm.de>
Index: c/src/libchip/ide/ata.c
===================================================================
--- c/src/libchip/ide/ata.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/ide/ata.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -135,5 +135,5 @@
                                            */
     rtems_device_minor_number  ctrl_minor;
-    unsigned8                  dev;
+    uint8_t                    dev;
     
     rel_minor = (rtems_filesystem_dev_minor_t(device)) / 
@@ -218,13 +218,13 @@
     if (ATA_DEV_INFO(ctrl_minor, dev).lba_avaible)
     {
-        areq->regs.regs[IDE_REGISTER_LBA0] = (unsigned8)req->start;
-        areq->regs.regs[IDE_REGISTER_LBA1] = (unsigned8)(req->start >> 8);
-        areq->regs.regs[IDE_REGISTER_LBA2] = (unsigned8)(req->start >> 16);
-        areq->regs.regs[IDE_REGISTER_LBA3] |= (unsigned8) (req->start >> 24);
+        areq->regs.regs[IDE_REGISTER_LBA0] = (uint8_t  )req->start;
+        areq->regs.regs[IDE_REGISTER_LBA1] = (uint8_t  )(req->start >> 8);
+        areq->regs.regs[IDE_REGISTER_LBA2] = (uint8_t  )(req->start >> 16);
+        areq->regs.regs[IDE_REGISTER_LBA3] |= (uint8_t  ) (req->start >> 24);
         areq->regs.regs[IDE_REGISTER_LBA3] |= IDE_REGISTER_LBA3_L;
     }
     else
     {
-        unsigned32 count = req->start;
+        uint32_t   count = req->start;
 
         areq->regs.regs[IDE_REGISTER_SECTOR_NUMBER] =
@@ -238,6 +238,6 @@
         /* now count = number of cylinders */
         count %= ATA_DEV_INFO(ctrl_minor, dev).cylinders;
-        areq->regs.regs[IDE_REGISTER_CYLINDER_LOW] = (unsigned8)count;
-        areq->regs.regs[IDE_REGISTER_CYLINDER_HIGH] = (unsigned8)(count >> 8);
+        areq->regs.regs[IDE_REGISTER_CYLINDER_LOW] = (uint8_t  )count;
+        areq->regs.regs[IDE_REGISTER_CYLINDER_HIGH] = (uint8_t  )(count >> 8);
         areq->regs.regs[IDE_REGISTER_DEVICE_HEAD] &= 
                                                 ~IDE_REGISTER_DEVICE_HEAD_L;
@@ -275,5 +275,5 @@
                                            */
     rtems_device_minor_number  ctrl_minor;
-    unsigned8                  dev;
+    uint8_t                    dev;
     ata_queue_msg_t            msg;    
     
@@ -313,5 +313,5 @@
             areq->regs.to_write |= 
                                ATA_REGISTERS_VALUE(IDE_REGISTER_SECTOR_COUNT);
-            areq->regs.regs[IDE_REGISTER_SECTOR_COUNT] = *(unsigned8 *)argp;
+            areq->regs.regs[IDE_REGISTER_SECTOR_COUNT] = *(uint8_t   *)argp;
             break;
         
@@ -357,5 +357,5 @@
             case ATAIO_SET_MULTIPLE_MODE:
                 ATA_DEV_INFO(ctrl_minor, dev).current_multiple = 
-                                                           *(unsigned8 *)argp;
+                                                           *(uint8_t   *)argp;
                 break;
         
@@ -392,9 +392,9 @@
 {
     ata_req_t       *areq;
-    unsigned16       byte; /* emphasize that only 8 low bits is meaningful */
+    uint16_t         byte; /* emphasize that only 8 low bits is meaningful */
     ata_queue_msg_t  msg;
-    unsigned8        i, dev;
-    unsigned16       val;
-    unsigned16       data_bs; /* the number of 512-bytes sectors in one 
+    uint8_t          i, dev;
+    uint16_t         val;
+    uint16_t         data_bs; /* the number of 512-bytes sectors in one 
                                * data block 
                                */
@@ -430,5 +430,5 @@
     for (i=0; i< ATA_MAX_CMD_REG_OFFSET; i++)
     {
-        unsigned32 reg = (1 << i);
+        uint32_t   reg = (1 << i);
         if (areq->regs.to_write & reg)
             ide_controller_write_register(ctrl_minor, i, areq->regs.regs[i]);
@@ -555,5 +555,5 @@
     if (Chain_Has_only_one_node(&ata_ide_ctrls[ctrl_minor].reqs))
     {
-        unsigned16      val;
+        uint16_t        val;
         ata_queue_msg_t msg;
 
@@ -590,5 +590,5 @@
     Chain_Node      *the_node = ((Chain_Control *)(&ata_int_vec[vec]))->first;
     ata_queue_msg_t  msg;
-    unsigned16       byte; /* emphasize that only 8 low bits is meaningful */
+    uint16_t         byte; /* emphasize that only 8 low bits is meaningful */
     
     for ( ; !Chain_Is_tail(&ata_int_vec[vec], the_node) ; )
@@ -622,7 +622,7 @@
 ata_pio_in_protocol(rtems_device_minor_number ctrl_minor, ata_req_t *areq)
 {
-    unsigned16      bs, val;
-    unsigned8       dev;
-    unsigned32      min_val;
+    uint16_t        bs, val;
+    uint8_t         dev;
+    uint32_t        min_val;
     ata_queue_msg_t msg;
         
@@ -665,7 +665,7 @@
 ata_pio_out_protocol(rtems_device_minor_number ctrl_minor, ata_req_t *areq)
 {
-    unsigned16      bs, val;
-    unsigned8       dev;
-    unsigned32      min_val;
+    uint16_t        bs, val;
+    uint8_t         dev;
+    uint32_t        min_val;
     ata_queue_msg_t msg;
     
@@ -716,9 +716,9 @@
 {
     ata_queue_msg_t            msg;
-    rtems_unsigned32           size;
+    uint32_t             size;
     ata_req_t                 *areq;
     rtems_device_minor_number  ctrl_minor;
-    unsigned16                 val;
-    unsigned16                 val1;
+    uint16_t                   val;
+    uint16_t                   val1;
     rtems_status_code          rc;
     ISR_Level                  level;
@@ -898,11 +898,11 @@
                void *args)
 {
-    unsigned32         ctrl_minor;
+    uint32_t           ctrl_minor;
     rtems_status_code  status;
     ata_req_t          areq;
     blkdev_request1    breq;     
-    unsigned8          i, dev = 0;
-    unsigned16        *buffer;
-    unsigned16         ec;
+    uint8_t            i, dev = 0;
+    uint16_t          *buffer;
+    uint16_t           ec;
     char               name[ATA_MAX_NAME_LENGTH];
     dev_t              device;
@@ -963,5 +963,5 @@
     }    
     
-    buffer = (unsigned16 *)malloc(ATA_SECTOR_SIZE);
+    buffer = (uint16_t   *)malloc(ATA_SECTOR_SIZE);
     if (buffer == NULL)
     {
@@ -1148,8 +1148,8 @@
                 (CF_LE_W(buffer[ATA_IDENT_WORD_CAPABILITIES]) >> 9) & 0x1;
             ATA_DEV_INFO(ctrl_minor, dev).max_multiple = 
-                (unsigned8) (CF_LE_W(buffer[ATA_IDENT_WORD_RW_MULT]));
+                (uint8_t  ) (CF_LE_W(buffer[ATA_IDENT_WORD_RW_MULT]));
             ATA_DEV_INFO(ctrl_minor, dev).current_multiple = 
                 (CF_LE_W(buffer[ATA_IDENT_WORD_MULT_SECS]) & 0x100) ? 
-                (unsigned8)(CF_LE_W(buffer[ATA_IDENT_WORD_MULT_SECS])) :
+                (uint8_t  )(CF_LE_W(buffer[ATA_IDENT_WORD_MULT_SECS])) :
                  0;
 
@@ -1237,8 +1237,8 @@
                                   ata_req_t                 *areq)
 {
-    unsigned16         byte;/* emphasize that only 8 low bits is meaningful */
-    unsigned8          i, dev;
-    unsigned16         val, val1;
-    unsigned16         data_bs; /* the number of 512 bytes sectors into one 
+    uint16_t           byte;/* emphasize that only 8 low bits is meaningful */
+    uint8_t            i, dev;
+    uint16_t           val, val1;
+    uint16_t           data_bs; /* the number of 512 bytes sectors into one 
                                  * data block 
                                  */
@@ -1261,5 +1261,5 @@
     for (i=0; i< ATA_MAX_CMD_REG_OFFSET; i++)
     {
-        unsigned32 reg = (1 << i);
+        uint32_t   reg = (1 << i);
         if (areq->regs.to_write & reg)
             ide_controller_write_register(ctrl_minor, i, 
Index: c/src/libchip/ide/ata_internal.h
===================================================================
--- c/src/libchip/ide/ata_internal.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/ide/ata_internal.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -211,7 +211,7 @@
 /* Command block registers */
 typedef struct ata_registers_s {
-    unsigned16 regs[8];  /* command block registers */
-    unsigned16 to_read;  /* mask: which ata registers should be read */
-    unsigned16 to_write; /* mask: which ata registers should be written */
+    uint16_t   regs[8];  /* command block registers */
+    uint16_t   to_read;  /* mask: which ata registers should be read */
+    uint16_t   to_write; /* mask: which ata registers should be written */
 } ata_registers_t;
 
@@ -221,7 +221,7 @@
     char              type;   /* request type */
     ata_registers_t   regs;   /* ATA command */
-    rtems_unsigned32  cnt;    /* Number of sectors to be exchanged */
-    rtems_unsigned32  cbuf;   /* number of current buffer from breq in use */
-    rtems_unsigned32  pos;    /* current position in 'cbuf' */
+    uint32_t    cnt;    /* Number of sectors to be exchanged */
+    uint32_t    cbuf;   /* number of current buffer from breq in use */
+    uint32_t    pos;    /* current position in 'cbuf' */
     blkdev_request   *breq;   /* blkdev_request which corresponds to the 
                                * ata request
@@ -296,19 +296,19 @@
  */
 typedef struct ata_dev_s {
-    signed8     present;     /* 1 -- present, 0 -- not present, */
+    int8_t       present;     /* 1 -- present, 0 -- not present, */
                              /* -1 -- non-initialized */
-    unsigned16  cylinders;
-    unsigned16  heads;
-    unsigned16  sectors;
-    unsigned32  lba_sectors;  /* for small disk */
+    uint16_t    cylinders;
+    uint16_t    heads;
+    uint16_t    sectors;
+    uint32_t    lba_sectors;  /* for small disk */
                               /* == cylinders * heads * sectors */
 
-    unsigned8   lba_avaible;  /* 0 - CHS mode, 1 - LBA mode */
-
-    unsigned8   max_multiple; /* 0 if READ/WRITE MULTIPLE is unsupported */
-    unsigned8   current_multiple;
-
-    unsigned8   modes_avaible; /* OR of values for this modes */
-    unsigned8   mode_active;
+    uint8_t     lba_avaible;  /* 0 - CHS mode, 1 - LBA mode */
+
+    uint8_t     max_multiple; /* 0 if READ/WRITE MULTIPLE is unsupported */
+    uint8_t     current_multiple;
+
+    uint8_t     modes_avaible; /* OR of values for this modes */
+    uint8_t     mode_active;
 } ata_dev_t;
 
Index: c/src/libchip/ide/ide_controller.c
===================================================================
--- c/src/libchip/ide/ide_controller.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/ide/ide_controller.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -85,8 +85,8 @@
 void
 ide_controller_read_data_block(rtems_device_minor_number  minor,
-                               unsigned16                 block_size,
+                               uint16_t                   block_size,
                                blkdev_sg_buffer          *bufs,
-                               rtems_unsigned32          *cbuf,
-                               rtems_unsigned32          *pos)
+                               uint32_t            *cbuf,
+                               uint32_t            *pos)
 {
     IDE_Controller_Table[minor].fns->ctrl_read_block(minor, block_size, bufs,
@@ -110,8 +110,8 @@
 void
 ide_controller_write_data_block(rtems_device_minor_number  minor,
-                                unsigned16                 block_size,
+                                uint16_t                   block_size,
                                 blkdev_sg_buffer          *bufs,
-                                rtems_unsigned32          *cbuf,
-                                rtems_unsigned32          *pos)
+                                uint32_t            *cbuf,
+                                uint32_t            *pos)
 
 {
@@ -135,5 +135,5 @@
 ide_controller_read_register(rtems_device_minor_number  minor,
                              int                        reg, 
-                             unsigned16                *value)
+                             uint16_t                  *value)
 {
     IDE_Controller_Table[minor].fns->ctrl_reg_read(minor, reg, value);
@@ -154,5 +154,5 @@
 void
 ide_controller_write_register(rtems_device_minor_number minor, int reg, 
-                              unsigned16 value)
+                              uint16_t   value)
 {
     IDE_Controller_Table[minor].fns->ctrl_reg_write(minor, reg, value);
@@ -172,5 +172,5 @@
  */
 rtems_status_code 
-ide_controller_config_io_speed(int minor, unsigned8 modes_avaible)
+ide_controller_config_io_speed(int minor, uint8_t   modes_avaible)
 {
     return IDE_Controller_Table[minor].fns->ctrl_config_io_speed(
Index: c/src/libchip/ide/ide_ctrl_cfg.h
===================================================================
--- c/src/libchip/ide/ide_ctrl_cfg.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/ide/ide_ctrl_cfg.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -39,5 +39,5 @@
     boolean           (*ctrl_probe)(int minor); /* probe routine */
     void              (*ctrl_initialize)(int minor);
-    int               (*ctrl_control)(int minor, unsigned32 command, 
+    int               (*ctrl_control)(int minor, uint32_t   command, 
                                       void *arg);
     /*
@@ -46,6 +46,6 @@
      * ide_controller_write_register)
      */
-    void    (*ctrl_reg_read)(int minor, int regist, unsigned16 *value);
-    void    (*ctrl_reg_write)(int minor, int regist, unsigned16 value);
+    void    (*ctrl_reg_read)(int minor, int regist, uint16_t   *value);
+    void    (*ctrl_reg_write)(int minor, int regist, uint16_t   value);
     
     /* 
@@ -53,13 +53,13 @@
      * functions calls
      */
-    void  (*ctrl_read_block)(int minor, unsigned16 block_size, 
-                             blkdev_sg_buffer *bufs, rtems_unsigned32 *cbuf,
-                             rtems_unsigned32 *pos);
-    void  (*ctrl_write_block)(int minor, unsigned16 block_size,
-                              blkdev_sg_buffer *bufs, rtems_unsigned32 *cbuf,
-                              rtems_unsigned32 *pos);
+    void  (*ctrl_read_block)(int minor, uint16_t   block_size, 
+                             blkdev_sg_buffer *bufs, uint32_t   *cbuf,
+                             uint32_t   *pos);
+    void  (*ctrl_write_block)(int minor, uint16_t   block_size,
+                              blkdev_sg_buffer *bufs, uint32_t   *cbuf,
+                              uint32_t   *pos);
     
     rtems_status_code (*ctrl_config_io_speed)(int minor, 
-                                              unsigned8 modes_available);
+                                              uint8_t   modes_available);
 } ide_ctrl_fns_t;
 
@@ -73,8 +73,8 @@
     ide_ctrl_fns_t      *fns;   /* pointer to the set of driver routines */
     boolean              (*probe)(int minor); /* general probe routine */
-    unsigned8            status; /* initialized/non initialized. Should be set 
+    uint8_t              status; /* initialized/non initialized. Should be set 
                                   * to zero by static initialization  
                                   */
-    unsigned32           port1; /* port number for the port of the device */
+    uint32_t             port1; /* port number for the port of the device */
     rtems_boolean        int_driven; /* interrupt/poll driven */
     rtems_vector_number  int_vec; /* the interrupt vector of the device */
Index: c/src/libchip/ide/ide_ctrl_io.h
===================================================================
--- c/src/libchip/ide/ide_ctrl_io.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/ide/ide_ctrl_io.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -104,8 +104,8 @@
 void
 ide_controller_read_data_block(rtems_device_minor_number  minor,
-                               unsigned16                 block_size,
+                               uint16_t                   block_size,
                                blkdev_sg_buffer          *bufs,
-                               rtems_unsigned32          *cbuf,
-                               rtems_unsigned32          *pos);
+                               uint32_t            *cbuf,
+                               uint32_t            *pos);
 
 /*
@@ -125,8 +125,8 @@
 void
 ide_controller_write_data_block(rtems_device_minor_number  minor,
-                                unsigned16                 block_size,
+                                uint16_t                   block_size,
                                 blkdev_sg_buffer          *bufs,
-                               rtems_unsigned32           *cbuf,
-                               rtems_unsigned32           *pos);
+                               uint32_t             *cbuf,
+                               uint32_t             *pos);
 
 /*
@@ -145,5 +145,5 @@
 ide_controller_read_register(rtems_device_minor_number  minor,
                              int                        reg, 
-                             unsigned16                *value);
+                             uint16_t                  *value);
 
 /*
@@ -161,5 +161,5 @@
 void
 ide_controller_write_register(rtems_device_minor_number minor,
-                              int reg, unsigned16 value);
+                              int reg, uint16_t   value);
 
 /*
@@ -176,5 +176,5 @@
  */
 rtems_status_code 
-ide_controller_config_io_speed(int minor, unsigned8 modes_avaible);
+ide_controller_config_io_speed(int minor, uint8_t   modes_avaible);
 
 #ifdef __cplusplus
Index: c/src/libchip/network/cs8900.c
===================================================================
--- c/src/libchip/network/cs8900.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/cs8900.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -199,5 +199,5 @@
  */
 
-rtems_unsigned32 rtems_read_timer ();
+uint32_t   rtems_read_timer ();
 
 static inline void
Index: c/src/libchip/network/dec21140.c
===================================================================
--- c/src/libchip/network/dec21140.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/dec21140.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -171,7 +171,7 @@
 struct MD {
     /* used by hardware */
-    volatile unsigned32 status;
-    volatile unsigned32 counts;
-    volatile unsigned32 buf1, buf2;  
+    volatile uint32_t   status;
+    volatile uint32_t   counts;
+    volatile uint32_t   buf1, buf2;  
     /* used by software */
     volatile struct mbuf *m;
@@ -244,10 +244,10 @@
 #define CPU_CACHE_ALIGNMENT_FOR_BUFFER PG_SIZE
 
-inline void st_le32(volatile unsigned32 *addr, unsigned32 value)
+inline void st_le32(volatile uint32_t   *addr, uint32_t   value)
 {
   *(addr)=value ;
 }
 
-inline unsigned32 ld_le32(volatile unsigned32 *addr)
+inline uint32_t   ld_le32(volatile uint32_t   *addr)
 {
   return(*addr);
@@ -426,8 +426,8 @@
 dec21140Enet_interrupt_handler ( struct dec21140_softc *sc )
 {
-   volatile unsigned32    *tbase;
-   unsigned32             status;
-
-   tbase = (unsigned32 *)(sc->base);
+   volatile uint32_t      *tbase;
+   uint32_t               status;
+
+   tbase = (uint32_t   *)(sc->base);
 
    /*
@@ -1191,5 +1191,5 @@
    pci_write_config_word(pbus, pdev, pfun,
                          PCI_COMMAND,
-                         (unsigned16) ( PCI_COMMAND_MEMORY |
+                         (uint16_t  ) ( PCI_COMMAND_MEMORY |
                                         PCI_COMMAND_MASTER | 
                                         PCI_COMMAND_INVALIDATE | 
Index: c/src/libchip/network/elnk.c
===================================================================
--- c/src/libchip/network/elnk.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/elnk.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -205,10 +205,10 @@
 #define CPU_CACHE_ALIGNMENT_FOR_BUFFER PG_SIZE
 
-inline void st_le32(volatile unsigned32 *addr, unsigned32 value)
+inline void st_le32(volatile uint32_t   *addr, uint32_t   value)
 {
   *(addr)=value ;
 }
 
-inline unsigned32 ld_le32(volatile unsigned32 *addr)
+inline uint32_t   ld_le32(volatile uint32_t   *addr)
 {
   return(*addr);
@@ -880,8 +880,8 @@
 {
       /* used by hardware */
-      volatile unsigned32 next;
-      volatile unsigned32 status;
-      volatile unsigned32 addr;
-      volatile unsigned32 length;
+      volatile uint32_t   next;
+      volatile uint32_t   status;
+      volatile uint32_t   addr;
+      volatile uint32_t   length;
       /* used by software */
       struct mbuf       *mbuf;        /* scratch variable used in the tx ring */
@@ -901,6 +901,6 @@
 struct tfrag
 {
-      volatile unsigned32 addr;
-      volatile unsigned32 length;
+      volatile uint32_t   addr;
+      volatile uint32_t   length;
 } __attribute__ ((packed));
 
@@ -908,6 +908,6 @@
 {
       /* used by hardware */
-      volatile unsigned32 next;
-      volatile unsigned32 status;
+      volatile uint32_t   next;
+      volatile uint32_t   status;
       struct tfrag        txfrags[NUM_FRAGS];
       /* used by software */
@@ -941,5 +941,5 @@
 
       rtems_id                  stat_timer_id;
-      unsigned32                stats_update_ticks;
+      uint32_t                  stats_update_ticks;
 
       struct xl_stats           xl_stats;
@@ -2048,5 +2048,5 @@
 #if 0
    {
-      unsigned16 intstatus, intenable, indenable;
+      uint16_t   intstatus, intenable, indenable;
 
       intstatus = CSR_READ_2(sc, XL_STATUS );
@@ -2133,5 +2133,5 @@
       for(i=0 ; i<sc->numRxbuffers; i++)
       {
-         if( ((unsigned32)&sc->rx_ring[i] & 0x7) )
+         if( ((uint32_t  )&sc->rx_ring[i] & 0x7) )
          {
             rtems_panic ("etherlink : unit elnk%d rx ring entry %d not aligned to 8 bytes\n", sc->xl_unit, i );
@@ -2152,6 +2152,6 @@
 
          st_le32( &sc->rx_ring[i].status, 0);
-         st_le32( &sc->rx_ring[i].next, (unsigned32)phys_to_bus( nxtmd ));
-         st_le32( &sc->rx_ring[i].addr, (unsigned32)phys_to_bus( mtod(m, void *) ));
+         st_le32( &sc->rx_ring[i].next, (uint32_t  )phys_to_bus( nxtmd ));
+         st_le32( &sc->rx_ring[i].addr, (uint32_t  )phys_to_bus( mtod(m, void *) ));
          st_le32( &sc->rx_ring[i].length, XL_LAST_FRAG | XL_PACKET_SIZE );
       }
@@ -2182,5 +2182,5 @@
       for(i=0 ; i<sc->numTxbuffers; i++)
       {
-         if( ((unsigned32)&sc->tx_ring[i] & 0x7) )
+         if( ((uint32_t  )&sc->tx_ring[i] & 0x7) )
          {
             rtems_panic ("etherlink : unit elnk%d tx ring entry %d not aligned to 8 bytes\n", sc->xl_unit, i );
@@ -2328,5 +2328,5 @@
                         rmd->mbuf   = m;
                         st_le32( &rmd->status, 0 );
-                        st_le32( &rmd->addr, (unsigned32)phys_to_bus(mtod(m, void *)) );
+                        st_le32( &rmd->addr, (uint32_t  )phys_to_bus(mtod(m, void *)) );
                      }
                      else
@@ -2416,5 +2416,5 @@
                   {
                      struct TXMD *chainhead, *chaintail;
-                     unsigned32  esize;
+                     uint32_t    esize;
 
                      if( rtems_message_queue_receive( chainRecoveryQueue, &chainhead, &esize,
@@ -2476,5 +2476,5 @@
                      {
                         st_le32( &nextmd->txfrags[i].length, ((m->m_next)?0:XL_LAST_FRAG) | ( m->m_len & XL_TXSTAT_LENMASK) );
-                        st_le32( &nextmd->txfrags[i].addr, (unsigned32)phys_to_bus( m->m_data ) );
+                        st_le32( &nextmd->txfrags[i].addr, (uint32_t  )phys_to_bus( m->m_data ) );
                         if ((m = m->m_next) == NULL)
                            break;
@@ -2492,5 +2492,5 @@
                      char *pkt = bus_to_phys( ld_le32( &nextmd->txfrags[i].addr )), *delim;
                      int  i;
-                     printk("unit %d queued  pkt (%08x) ", sc->xl_unit, (unsigned32)pkt );
+                     printk("unit %d queued  pkt (%08x) ", sc->xl_unit, (uint32_t  )pkt );
                      for(delim="", i=0; i < sizeof(struct ether_header); i++, delim=":")
                         printk("%s%02x", delim, (char) pkt[i] ); 
@@ -2523,5 +2523,5 @@
                   {
                      /* hook this packet to the previous one */
-                     st_le32( &lastmd->next, (unsigned32)phys_to_bus( nextmd ));
+                     st_le32( &lastmd->next, (uint32_t  )phys_to_bus( nextmd ));
                   }
 
@@ -2575,5 +2575,5 @@
                          sc->xl_unit, 
                          chainCount, 
-                         (unsigned32)ld_le32( &lastmd->status) );
+                         (uint32_t  )ld_le32( &lastmd->status) );
 #endif
 
@@ -2658,5 +2658,5 @@
 
       {
-         unsigned32 cr,sr;
+         uint32_t   cr,sr;
 
          xl_miibus_writereg(sc, 0x18, MII_BMCR, BMCR_RESET );
@@ -2928,5 +2928,5 @@
    {
       struct TXMD *chainhead;
-      unsigned32  esize;
+      uint32_t    esize;
 
       while( rtems_message_queue_receive( chainRecoveryQueue, &chainhead, &esize,
@@ -3330,5 +3330,5 @@
    pci_write_config_word(pbus, pdev, pfun,
                          PCI_COMMAND,
-                         (unsigned16)( PCI_COMMAND_IO | 
+                         (uint16_t  )( PCI_COMMAND_IO | 
                                        PCI_COMMAND_MASTER | 
                                        PCI_COMMAND_INVALIDATE | 
@@ -3341,5 +3341,5 @@
                          &lvalue);
 
-   sc->ioaddr = (unsigned32)lvalue & PCI_BASE_ADDRESS_IO_MASK;
+   sc->ioaddr = (uint32_t  )lvalue & PCI_BASE_ADDRESS_IO_MASK;
    /*
    ** Store the interrupt name, we'll use it later when we initialize
@@ -3361,6 +3361,6 @@
 
    {
-      unsigned8 pci_latency;
-      unsigned8 new_latency = 248;
+      uint8_t   pci_latency;
+      uint8_t   new_latency = 248;
 
       /* Check the PCI latency value.  On the 3c590 series the latency timer
Index: c/src/libchip/network/if_fxp.c
===================================================================
--- c/src/libchip/network/if_fxp.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/if_fxp.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -77,5 +77,5 @@
 #include <pcibios.h>
 #include <irq.h>
-#include "pci.h"
+#include <rtems/pci.h>
 
 #ifdef NS
Index: c/src/libchip/network/open_eth.c
===================================================================
--- c/src/libchip/network/open_eth.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/open_eth.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -163,5 +163,5 @@
 open_eth_interrupt_handler (rtems_vector_number v)
 {
-    unsigned32 status;
+    uint32_t   status;
 
     /* read and clear interrupt cause */
@@ -191,5 +191,5 @@
 }
 
-static unsigned32 read_mii(unsigned32 addr)
+static uint32_t   read_mii(uint32_t   addr)
 {
     while (oc.regs->miistatus & OETH_MIISTATUS_BUSY) {}
@@ -205,5 +205,5 @@
 }
 
-static void write_mii(unsigned32 addr, unsigned32 data)
+static void write_mii(uint32_t   addr, uint32_t   data)
 {
     while (oc.regs->miistatus & OETH_MIISTATUS_BUSY) {}
@@ -301,5 +301,5 @@
 	  m->m_pkthdr.rcvif = &sc->arpcom.ac_if;
 	  sc->rxdesc[i].m = m;
-	  sc->regs->xd[i + sc->txbufs].addr = mtod (m, unsigned32 *);
+	  sc->regs->xd[i + sc->txbufs].addr = mtod (m, uint32_t   *);
 	  sc->regs->xd[i + sc->txbufs].len_status =
 	      OETH_RX_BD_EMPTY | OETH_RX_BD_IRQ;
@@ -419,5 +419,5 @@
 		      dp->rxdesc[dp->rx_ptr].m = m;
 		      dp->regs->xd[dp->rx_ptr + dp->txbufs].addr =
-			  (unsigned32 *) mtod (m, void *);
+			  (uint32_t   *) mtod (m, void *);
 		      dp->rxPackets++;
 		  }
@@ -459,5 +459,5 @@
     len = 0;
     temp = (unsigned char *) dp->txdesc[dp->tx_ptr].buf;
-    dp->regs->xd[dp->tx_ptr].addr = (unsigned32 *) temp;
+    dp->regs->xd[dp->tx_ptr].addr = (uint32_t   *) temp;
 
 #ifdef OPEN_ETH_DEBUG
Index: c/src/libchip/network/open_eth.h
===================================================================
--- c/src/libchip/network/open_eth.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/open_eth.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -9,8 +9,8 @@
 
 typedef struct {
-  unsigned32              base_address;
-  unsigned32              vector;
-  unsigned32              txd_count;
-  unsigned32              rxd_count;
+  uint32_t                base_address;
+  uint32_t                vector;
+  uint32_t                txd_count;
+  uint32_t                rxd_count;
 } open_eth_configuration_t;
 
@@ -19,6 +19,6 @@
 
 typedef struct _oeth_rxtxdesc {
-    volatile unsigned32 len_status; /* Length and status */
-    volatile unsigned32 *addr;      /* Buffer pointer */
+    volatile uint32_t   len_status; /* Length and status */
+    volatile uint32_t   *addr;      /* Buffer pointer */
 } oeth_rxtxdesc;
 
@@ -26,26 +26,26 @@
 
 typedef struct _oeth_regs {
-    volatile unsigned32 moder;       /* Mode Register */
-    volatile unsigned32 int_src;     /* Interrupt Source Register */
-    volatile unsigned32 int_mask;    /* Interrupt Mask Register */
-    volatile unsigned32 ipgt;        /* Back to Bak Inter Packet Gap Register */
-    volatile unsigned32 ipgr1;       /* Non Back to Back Inter Packet Gap Register 1 */
-    volatile unsigned32 ipgr2;       /* Non Back to Back Inter Packet Gap Register 2 */
-    volatile unsigned32 packet_len;  /* Packet Length Register (min. and max.) */
-    volatile unsigned32 collconf;    /* Collision and Retry Configuration Register */
-    volatile unsigned32 tx_bd_num;   /* Transmit Buffer Descriptor Number Register */
-    volatile unsigned32 ctrlmoder;   /* Control Module Mode Register */
-    volatile unsigned32 miimoder;    /* MII Mode Register */
-    volatile unsigned32 miicommand;  /* MII Command Register */
-    volatile unsigned32 miiaddress;  /* MII Address Register */
-    volatile unsigned32 miitx_data;  /* MII Transmit Data Register */
-    volatile unsigned32 miirx_data;  /* MII Receive Data Register */
-    volatile unsigned32 miistatus;   /* MII Status Register */
-    volatile unsigned32 mac_addr0;   /* MAC Individual Address Register 0 */
-    volatile unsigned32 mac_addr1;   /* MAC Individual Address Register 1 */
-    volatile unsigned32 hash_addr0;  /* Hash Register 0 */
-    volatile unsigned32 hash_addr1;  /* Hash Register 1 */
-    volatile unsigned32 txctrl;      /* Transmitter control register */
-    unsigned32 empty[235];	     /* Unused space */
+    volatile uint32_t   moder;       /* Mode Register */
+    volatile uint32_t   int_src;     /* Interrupt Source Register */
+    volatile uint32_t   int_mask;    /* Interrupt Mask Register */
+    volatile uint32_t   ipgt;        /* Back to Bak Inter Packet Gap Register */
+    volatile uint32_t   ipgr1;       /* Non Back to Back Inter Packet Gap Register 1 */
+    volatile uint32_t   ipgr2;       /* Non Back to Back Inter Packet Gap Register 2 */
+    volatile uint32_t   packet_len;  /* Packet Length Register (min. and max.) */
+    volatile uint32_t   collconf;    /* Collision and Retry Configuration Register */
+    volatile uint32_t   tx_bd_num;   /* Transmit Buffer Descriptor Number Register */
+    volatile uint32_t   ctrlmoder;   /* Control Module Mode Register */
+    volatile uint32_t   miimoder;    /* MII Mode Register */
+    volatile uint32_t   miicommand;  /* MII Command Register */
+    volatile uint32_t   miiaddress;  /* MII Address Register */
+    volatile uint32_t   miitx_data;  /* MII Transmit Data Register */
+    volatile uint32_t   miirx_data;  /* MII Receive Data Register */
+    volatile uint32_t   miistatus;   /* MII Status Register */
+    volatile uint32_t   mac_addr0;   /* MAC Individual Address Register 0 */
+    volatile uint32_t   mac_addr1;   /* MAC Individual Address Register 1 */
+    volatile uint32_t   hash_addr0;  /* Hash Register 0 */
+    volatile uint32_t   hash_addr1;  /* Hash Register 1 */
+    volatile uint32_t   txctrl;      /* Transmitter control register */
+    uint32_t   empty[235];	     /* Unused space */
     oeth_rxtxdesc xd[128];	     /* TX & RX descriptors */
 } oeth_regs;
Index: c/src/libchip/network/sonic.c
===================================================================
--- c/src/libchip/network/sonic.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/sonic.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -59,5 +59,5 @@
  */
 
-void *set_vector(void *, unsigned32, unsigned32);
+void *set_vector(void *, uint32_t  , uint32_t  );
 
 #if (SONIC_DEBUG & SONIC_DEBUG_DUMP_MBUFS)
@@ -117,7 +117,7 @@
  * Macros for manipulating 32-bit pointers as 16-bit fragments
  */
-#define LSW(p)   ((rtems_unsigned16)((rtems_unsigned32)(p)))
-#define MSW(p)   ((rtems_unsigned16)((rtems_unsigned32)(p) >> 16))
-#define PTR(m,l) ((void*)(((rtems_unsigned16)(m)<<16)|(rtems_unsigned16)(l)))
+#define LSW(p)   ((uint16_t  )((uint32_t  )(p)))
+#define MSW(p)   ((uint16_t  )((uint32_t  )(p) >> 16))
+#define PTR(m,l) ((void*)(((uint16_t  )(m)<<16)|(uint16_t  )(l)))
 
 /*
@@ -152,6 +152,6 @@
    * Data Configuration Register values
    */
-  rtems_unsigned32                dcr_value;
-  rtems_unsigned32                dc2_value;
+  uint32_t                  dcr_value;
+  uint32_t                  dc2_value;
 
   /*
@@ -264,5 +264,5 @@
 void sonic_enable_interrupts(
   struct sonic_softc *sc,
-  unsigned32  mask
+  uint32_t    mask
 )
 {
@@ -281,5 +281,5 @@
 void sonic_disable_interrupts(
   struct sonic_softc *sc,
-  unsigned32  mask
+  uint32_t    mask
 )
 {
@@ -298,5 +298,5 @@
 void sonic_clear_interrupts(
   struct sonic_softc *sc,
-  unsigned32  mask
+  uint32_t    mask
 )
 {
@@ -311,5 +311,5 @@
 void sonic_command(
   struct sonic_softc *sc,
-  unsigned32  mask
+  uint32_t    mask
 )
 {
@@ -403,5 +403,5 @@
 {
   struct sonic_softc *sc = sonic_softc;
-  unsigned32 isr, imr;
+  uint32_t   isr, imr;
   void *rp;
 
@@ -466,5 +466,5 @@
 SONIC_STATIC void sonic_retire_tda (struct sonic_softc *sc)
 {
-  rtems_unsigned16 status;
+  uint16_t   status;
   unsigned int collisions;
   struct mbuf *m, *n;
@@ -501,5 +501,5 @@
        * packets waiting to go.
        */
-      rtems_unsigned16 link;
+      uint16_t   link;
 #if (SONIC_DEBUG & SONIC_DEBUG_ERRORS)
       printf("restarting sonic after error\n");
@@ -931,8 +931,8 @@
   void *rp = sc->sonic;
   struct mbuf *m;
-  rtems_unsigned16 status;
+  uint16_t   status;
   ReceiveDescriptorPointer_t rdp;
   ReceiveResourcePointer_t rwp, rea;
-  rtems_unsigned16 newMissedTally, oldMissedTally;
+  uint16_t   newMissedTally, oldMissedTally;
 
   rwp = sc->rsa;
@@ -986,5 +986,5 @@
       m = rdp->mbufp;
       m->m_len = m->m_pkthdr.len = rdp->byte_count -
-                          sizeof(rtems_unsigned32) -
+                          sizeof(uint32_t  ) -
                           sizeof(struct ether_header);
       eh = mtod (m, struct ether_header *);
Index: c/src/libchip/network/sonic.h
===================================================================
--- c/src/libchip/network/sonic.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/network/sonic.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -72,20 +72,20 @@
 typedef void (*sonic_write_register_t)(
   void       *base,
-  unsigned32  regno,
-  unsigned32  value
+  uint32_t    regno,
+  uint32_t    value
 );
 
-typedef unsigned32 (*sonic_read_register_t)(
+typedef uint32_t   (*sonic_read_register_t)(
   void       *base,
-  unsigned32  regno
+  uint32_t    regno
 );
 
 typedef struct {
-  unsigned32              base_address;
-  unsigned32              vector;
-  unsigned32              dcr_value;
-  unsigned32              dc2_value;
-  unsigned32              tda_count;
-  unsigned32              rda_count;
+  uint32_t                base_address;
+  uint32_t                vector;
+  uint32_t                dcr_value;
+  uint32_t                dc2_value;
+  uint32_t                tda_count;
+  uint32_t                rda_count;
   sonic_write_register_t  write_register;
   sonic_read_register_t   read_register;
@@ -303,8 +303,8 @@
 #define MAXIMUM_FRAGS_PER_DESCRIPTOR    6
 struct TransmitDescriptor {
-  rtems_unsigned32        status;
-  rtems_unsigned32        pkt_config;
-  rtems_unsigned32        pkt_size;
-  rtems_unsigned32        frag_count;
+  uint32_t          status;
+  uint32_t          pkt_config;
+  uint32_t          pkt_size;
+  uint32_t          frag_count;
 
   /*
@@ -312,8 +312,8 @@
    */
   struct TransmitDescriptorFragLink {
-      rtems_unsigned32 frag_lsw;  /* LSW of fragment address */
+      uint32_t   frag_lsw;  /* LSW of fragment address */
 #define                      frag_link frag_lsw
-      rtems_unsigned32 frag_msw;  /* MSW of fragment address */
-      rtems_unsigned32 frag_size;
+      uint32_t   frag_msw;  /* MSW of fragment address */
+      uint32_t   frag_size;
   }                       frag[MAXIMUM_FRAGS_PER_DESCRIPTOR];
 
@@ -321,5 +321,5 @@
    * Space for link if all fragment pointers are used.
    */
-  rtems_unsigned32        link_pad;
+  uint32_t          link_pad;
 
   /*
@@ -328,5 +328,5 @@
   struct TransmitDescriptor       *next;  /* Circularly-linked list */
   struct mbuf                     *mbufp; /* First mbuf in packet */
-  volatile rtems_unsigned32       *linkp; /* Pointer to un[xxx].link */
+  volatile uint32_t         *linkp; /* Pointer to un[xxx].link */
 };
 typedef struct TransmitDescriptor TransmitDescriptor_t;
@@ -379,8 +379,8 @@
  */
 struct ReceiveResource {
-  rtems_unsigned32        buff_ptr_lsw;   /* LSW of RBA address */
-  rtems_unsigned32        buff_ptr_msw;   /* MSW of RBA address */
-  rtems_unsigned32        buff_wc_lsw;    /* LSW of RBA size (16-bit words) */
-  rtems_unsigned32        buff_wc_msw;    /* MSW of RBA size (16-bit words) */
+  uint32_t          buff_ptr_lsw;   /* LSW of RBA address */
+  uint32_t          buff_ptr_msw;   /* MSW of RBA address */
+  uint32_t          buff_wc_lsw;    /* LSW of RBA size (16-bit words) */
+  uint32_t          buff_wc_msw;    /* MSW of RBA size (16-bit words) */
 };
 typedef struct ReceiveResource ReceiveResource_t;
@@ -392,11 +392,11 @@
  */
 struct ReceiveDescriptor {
-  rtems_unsigned32        status;
-  rtems_unsigned32        byte_count;
-  rtems_unsigned32        pkt_lsw;        /* LSW of packet address */
-  rtems_unsigned32        pkt_msw;        /* MSW of packet address */
-  rtems_unsigned32        seq_no;
-  rtems_unsigned32        link;
-  rtems_unsigned32        in_use;
+  uint32_t          status;
+  uint32_t          byte_count;
+  uint32_t          pkt_lsw;        /* LSW of packet address */
+  uint32_t          pkt_msw;        /* MSW of packet address */
+  uint32_t          seq_no;
+  uint32_t          link;
+  uint32_t          in_use;
 
   /*
@@ -410,9 +410,9 @@
 
 typedef struct {
-  rtems_unsigned32  cep;  /* CAM Entry Pointer */
-  rtems_unsigned32  cap0; /* CAM Address Port 0 xx-xx-xx-xx-YY-YY */
-  rtems_unsigned32  cap1; /* CAM Address Port 1 xx-xx-YY-YY-xxxx */
-  rtems_unsigned32  cap2; /* CAM Address Port 2 YY-YY-xx-xx-xx-xx */
-  rtems_unsigned32  ce;
+  uint32_t    cep;  /* CAM Entry Pointer */
+  uint32_t    cap0; /* CAM Address Port 0 xx-xx-xx-xx-YY-YY */
+  uint32_t    cap1; /* CAM Address Port 1 xx-xx-YY-YY-xxxx */
+  uint32_t    cap2; /* CAM Address Port 2 YY-YY-xx-xx-xx-xx */
+  uint32_t    ce;
 } CamDescriptor_t;
 
Index: c/src/libchip/rtc/icm7170.c
===================================================================
--- c/src/libchip/rtc/icm7170.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -42,7 +42,7 @@
 )
 {
-  unsigned32     icm7170;
+  uint32_t       icm7170;
   setRegister_f  setReg;            
-  unsigned32     clock;
+  uint32_t       clock;
 
   icm7170 = RTC_Table[ minor ].ulCtrlPort1;
@@ -53,5 +53,5 @@
    */
 
-  clock = (unsigned32) RTC_Table[ minor ].pDeviceParams;
+  clock = (uint32_t  ) RTC_Table[ minor ].pDeviceParams;
   (*setReg)( icm7170, ICM7170_CONTROL, 0x0c | clock );
 }
@@ -66,8 +66,8 @@
 )
 {
-  unsigned32     icm7170;
+  uint32_t       icm7170;
   getRegister_f  getReg;
   setRegister_f  setReg;
-  unsigned32     year;
+  uint32_t       year;
 
   icm7170 = RTC_Table[ minor ].ulCtrlPort1;
@@ -119,14 +119,14 @@
 )
 {
-  unsigned32     icm7170;
+  uint32_t       icm7170;
   getRegister_f  getReg;
   setRegister_f  setReg;
-  unsigned32     year;
-  unsigned32     clock;
+  uint32_t       year;
+  uint32_t       clock;
 
   icm7170 = RTC_Table[ minor ].ulCtrlPort1;
   getReg = RTC_Table[ minor ].getRegister;
   setReg = RTC_Table[ minor ].setRegister;
-  clock = (unsigned32) RTC_Table[ minor ].pDeviceParams;
+  clock = (uint32_t  ) RTC_Table[ minor ].pDeviceParams;
 
   year = time->year;
Index: c/src/libchip/rtc/icm7170.h
===================================================================
--- c/src/libchip/rtc/icm7170.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -52,46 +52,46 @@
  */
 
-unsigned32 icm7170_get_register(    /* registers are at 1 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   icm7170_get_register(    /* registers are at 1 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  icm7170_set_register(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 icm7170_get_register_2(  /* registers are at 2 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   icm7170_get_register_2(  /* registers are at 2 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  icm7170_set_register_2(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 icm7170_get_register_4(  /* registers are at 4 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   icm7170_get_register_4(  /* registers are at 4 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  icm7170_set_register_4(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 icm7170_get_register_8(  /* registers are at 8 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   icm7170_get_register_8(  /* registers are at 8 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  icm7170_set_register_8(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
Index: c/src/libchip/rtc/icm7170_reg.c
===================================================================
--- c/src/libchip/rtc/icm7170_reg.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170_reg.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -21,5 +21,5 @@
 #define _ICM7170_MULTIPLIER 1
 #define _ICM7170_NAME(_X) _X
-#define _ICM7170_TYPE unsigned8
+#define _ICM7170_TYPE uint8_t  
 #endif
 
@@ -31,7 +31,7 @@
  */
 
-unsigned32 _ICM7170_NAME(icm7170_get_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint32_t   _ICM7170_NAME(icm7170_get_register)(
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 )
 {
@@ -48,7 +48,7 @@
 
 void  _ICM7170_NAME(icm7170_set_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 )
 {
Index: c/src/libchip/rtc/icm7170_reg2.c
===================================================================
--- c/src/libchip/rtc/icm7170_reg2.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170_reg2.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _ICM7170_MULTIPLIER 2
 #define _ICM7170_NAME(_X) _X##_2
-#define _ICM7170_TYPE unsigned8
+#define _ICM7170_TYPE uint8_t  
 
 #include "icm7170_reg.c"
Index: c/src/libchip/rtc/icm7170_reg4.c
===================================================================
--- c/src/libchip/rtc/icm7170_reg4.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170_reg4.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _ICM7170_MULTIPLIER 4
 #define _ICM7170_NAME(_X) _X##_4
-#define _ICM7170_TYPE unsigned8
+#define _ICM7170_TYPE uint8_t  
 
 #include "icm7170_reg.c"
Index: c/src/libchip/rtc/icm7170_reg8.c
===================================================================
--- c/src/libchip/rtc/icm7170_reg8.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/icm7170_reg8.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _ICM7170_MULTIPLIER 8
 #define _ICM7170_NAME(_X) _X##_8
-#define _ICM7170_TYPE unsigned8
+#define _ICM7170_TYPE uint8_t  
 
 #include "icm7170_reg.c"
Index: c/src/libchip/rtc/m48t08.c
===================================================================
--- c/src/libchip/rtc/m48t08.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -58,10 +58,10 @@
 )
 {
-  unsigned32     m48t08;
+  uint32_t       m48t08;
   getRegister_f  getReg;
   setRegister_f  setReg;
-  unsigned8      controlReg;
-  unsigned32     value1;
-  unsigned32     value2;
+  uint8_t        controlReg;
+  uint32_t       value1;
+  uint32_t       value2;
 
   m48t08 = RTC_Table[ minor ].ulCtrlPort1;
@@ -118,8 +118,8 @@
 )
 {
-  unsigned32     m48t08;
+  uint32_t       m48t08;
   getRegister_f  getReg;
   setRegister_f  setReg;
-  unsigned8      controlReg;
+  uint8_t        controlReg;
 
   m48t08 = RTC_Table[ minor ].ulCtrlPort1;
Index: c/src/libchip/rtc/m48t08.h
===================================================================
--- c/src/libchip/rtc/m48t08.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -42,46 +42,46 @@
  */
 
-unsigned32 m48t08_get_register(     /* registers are at 1 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   m48t08_get_register(     /* registers are at 1 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  m48t08_set_register(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 m48t08_get_register_2(   /* registers are at 2 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   m48t08_get_register_2(   /* registers are at 2 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  m48t08_set_register_2(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 m48t08_get_register_4(   /* registers are at 4 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   m48t08_get_register_4(   /* registers are at 4 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  m48t08_set_register_4(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
-unsigned32 m48t08_get_register_8(   /* registers are at 8 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint32_t   m48t08_get_register_8(   /* registers are at 8 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  m48t08_set_register_8(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 );
 
Index: c/src/libchip/rtc/m48t08_reg.c
===================================================================
--- c/src/libchip/rtc/m48t08_reg.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08_reg.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -21,5 +21,5 @@
 #define _M48T08_MULTIPLIER 1
 #define _M48T08_NAME(_X) _X
-#define _M48T08_TYPE unsigned8
+#define _M48T08_TYPE uint8_t  
 #endif
 
@@ -31,7 +31,7 @@
  */
 
-unsigned32 _M48T08_NAME(m48t08_get_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint32_t   _M48T08_NAME(m48t08_get_register)(
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 )
 {
@@ -48,7 +48,7 @@
 
 void  _M48T08_NAME(m48t08_set_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned32  ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint32_t    ucData
 )
 {
Index: c/src/libchip/rtc/m48t08_reg2.c
===================================================================
--- c/src/libchip/rtc/m48t08_reg2.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08_reg2.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _M48T08_MULTIPLIER 2
 #define _M48T08_NAME(_X) _X##_2
-#define _M48T08_TYPE unsigned8
+#define _M48T08_TYPE uint8_t  
 
 #include "m48t08_reg.c"
Index: c/src/libchip/rtc/m48t08_reg4.c
===================================================================
--- c/src/libchip/rtc/m48t08_reg4.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08_reg4.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _M48T08_MULTIPLIER 4
 #define _M48T08_NAME(_X) _X##_4
-#define _M48T08_TYPE unsigned8
+#define _M48T08_TYPE uint8_t  
 
 #include "m48t08_reg.c"
Index: c/src/libchip/rtc/m48t08_reg8.c
===================================================================
--- c/src/libchip/rtc/m48t08_reg8.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/m48t08_reg8.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _M48T08_MULTIPLIER 8
 #define _M48T08_NAME(_X) _X##_8
-#define _M48T08_TYPE unsigned8
+#define _M48T08_TYPE uint8_t  
 
 #include "m48t08_reg.c"
Index: c/src/libchip/rtc/rtc.h
===================================================================
--- c/src/libchip/rtc/rtc.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/rtc/rtc.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -20,7 +20,7 @@
  */
 
-typedef unsigned32 (*getRegister_f)(unsigned32 port, unsigned8 register);
+typedef uint32_t   (*getRegister_f)(uint32_t   port, uint8_t   register);
 typedef void       (*setRegister_f)(
-                            unsigned32 port, unsigned8 reg, unsigned32 value);
+                            uint32_t   port, uint8_t   reg, uint32_t   value);
 
 typedef struct _rtc_fns {
@@ -65,6 +65,6 @@
   boolean      (*deviceProbe)(int minor);
   void          *pDeviceParams;
-  unsigned32     ulCtrlPort1;
-  unsigned32     ulDataPort;
+  uint32_t       ulCtrlPort1;
+  uint32_t       ulDataPort;
   getRegister_f  getRegister;
   setRegister_f  setRegister;
Index: c/src/libchip/serial/mc68681.c
===================================================================
--- c/src/libchip/serial/mc68681.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -90,6 +90,6 @@
 )
 {
-  unsigned32             pMC68681_port;
-  unsigned32             pMC68681;
+  uint32_t               pMC68681_port;
+  uint32_t               pMC68681;
   unsigned int           mode1;
   unsigned int           mode2;
@@ -220,6 +220,6 @@
 MC68681_STATIC void mc68681_init(int minor)
 {
-  unsigned32              pMC68681_port;
-  unsigned32              pMC68681;
+  uint32_t                pMC68681_port;
+  uint32_t                pMC68681;
   mc68681_context        *pmc68681Context;
   setRegister_f           setReg;
@@ -274,6 +274,6 @@
 )
 {
-  unsigned32             pMC68681;
-  unsigned32             pMC68681_port;
+  uint32_t               pMC68681;
+  uint32_t               pMC68681_port;
   unsigned int           baud;
   unsigned int           acr_bit;
@@ -331,6 +331,6 @@
 )
 {
-  unsigned32      pMC68681;
-  unsigned32      pMC68681_port;
+  uint32_t        pMC68681;
+  uint32_t        pMC68681_port;
   setRegister_f   setReg;
 
@@ -362,5 +362,5 @@
 )
 {
-  unsigned32              pMC68681_port;
+  uint32_t                pMC68681_port;
   unsigned char           ucLineStatus;
   int                     iTimeout;
@@ -455,6 +455,6 @@
 )
 {
-  unsigned32      Irql;
-  unsigned32      pMC68681_port;
+  uint32_t        Irql;
+  uint32_t        pMC68681_port;
   setRegister_f   setReg;
 
@@ -527,5 +527,5 @@
 )
 {
-  unsigned32           pMC68681_port;
+  uint32_t             pMC68681_port;
   unsigned char        ucLineStatus;
   unsigned char        cChar;
@@ -624,8 +624,8 @@
 )
 {
-  unsigned32              pMC68681;
-  unsigned32              pMC68681_port;
-  volatile unsigned8      ucLineStatus; 
-  volatile unsigned8      ucISRStatus; 
+  uint32_t                pMC68681;
+  uint32_t                pMC68681_port;
+  volatile uint8_t        ucLineStatus; 
+  volatile uint8_t        ucISRStatus; 
   unsigned char           cChar;
   getRegister_f           getReg;
@@ -763,5 +763,5 @@
 )
 {
-  unsigned32            pMC68681;
+  uint32_t              pMC68681;
   setRegister_f         setReg;
 
Index: c/src/libchip/serial/mc68681.h
===================================================================
--- c/src/libchip/serial/mc68681.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -71,46 +71,46 @@
  */
 
-unsigned8 mc68681_get_register(     /* registers are at 1 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint8_t   mc68681_get_register(     /* registers are at 1 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  mc68681_set_register(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 );
 
-unsigned8 mc68681_get_register_2(   /* registers are at 2 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint8_t   mc68681_get_register_2(   /* registers are at 2 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  mc68681_set_register_2(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 );
 
-unsigned8 mc68681_get_register_4(   /* registers are at 4 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint8_t   mc68681_get_register_4(   /* registers are at 4 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  mc68681_set_register_4(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 );
 
-unsigned8 mc68681_get_register_8(   /* registers are at 8 byte boundaries */
-  unsigned32  ulCtrlPort,           /*   and accessed as bytes            */
-  unsigned8   ucRegNum
+uint8_t   mc68681_get_register_8(   /* registers are at 8 byte boundaries */
+  uint32_t    ulCtrlPort,           /*   and accessed as bytes            */
+  uint8_t     ucRegNum
 );
 
 void  mc68681_set_register_8(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 );
 
Index: c/src/libchip/serial/mc68681_reg.c
===================================================================
--- c/src/libchip/serial/mc68681_reg.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681_reg.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -21,5 +21,5 @@
 #define _MC68681_MULTIPLIER 1
 #define _MC68681_NAME(_X) _X
-#define _MC68681_TYPE unsigned8
+#define _MC68681_TYPE uint8_t  
 #endif
 
@@ -31,7 +31,7 @@
  */
 
-unsigned8 _MC68681_NAME(mc68681_get_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint8_t   _MC68681_NAME(mc68681_get_register)(
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 )
 {
@@ -48,7 +48,7 @@
 
 void  _MC68681_NAME(mc68681_set_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 )
 {
Index: c/src/libchip/serial/mc68681_reg2.c
===================================================================
--- c/src/libchip/serial/mc68681_reg2.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681_reg2.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _MC68681_MULTIPLIER 2
 #define _MC68681_NAME(_X) _X##_2
-#define _MC68681_TYPE unsigned8
+#define _MC68681_TYPE uint8_t  
 
 #include "mc68681_reg.c"
Index: c/src/libchip/serial/mc68681_reg4.c
===================================================================
--- c/src/libchip/serial/mc68681_reg4.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681_reg4.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _MC68681_MULTIPLIER 4
 #define _MC68681_NAME(_X) _X##_4
-#define _MC68681_TYPE unsigned8
+#define _MC68681_TYPE uint8_t  
 
 #include "mc68681_reg.c"
Index: c/src/libchip/serial/mc68681_reg8.c
===================================================================
--- c/src/libchip/serial/mc68681_reg8.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/mc68681_reg8.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -18,5 +18,5 @@
 #define _MC68681_MULTIPLIER 8
 #define _MC68681_NAME(_X) _X##_8
-#define _MC68681_TYPE unsigned8
+#define _MC68681_TYPE uint8_t  
 
 #include "mc68681_reg.c"
Index: c/src/libchip/serial/ns16550.c
===================================================================
--- c/src/libchip/serial/ns16550.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/ns16550.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -76,8 +76,8 @@
 NS16550_STATIC void ns16550_init(int minor)
 {
-  unsigned32              pNS16550;
-  unsigned8               ucTrash;
-  unsigned8               ucDataByte;
-  unsigned32              ulBaudDivisor;
+  uint32_t                pNS16550;
+  uint8_t                 ucTrash;
+  uint8_t                 ucDataByte;
+  uint32_t                ulBaudDivisor;
   ns16550_context        *pns16550Context;
   setRegister_f           setReg;
@@ -104,6 +104,6 @@
 
   ulBaudDivisor = NS16550_Baud(
-    (unsigned32) Console_Port_Tbl[minor].ulClock,
-    (unsigned32) Console_Port_Tbl[minor].pDeviceParams
+    (uint32_t  ) Console_Port_Tbl[minor].ulClock,
+    (uint32_t  ) Console_Port_Tbl[minor].pDeviceParams
   );
   ucDataByte = SP_LINE_DLAB;
@@ -186,5 +186,5 @@
 )
 {
-  unsigned32              pNS16550;
+  uint32_t                pNS16550;
   unsigned char           ucLineStatus;
   int                     iTimeout;
@@ -232,6 +232,6 @@
 NS16550_STATIC int ns16550_assert_RTS(int minor)
 {
-  unsigned32              pNS16550;
-  unsigned32              Irql;
+  uint32_t                pNS16550;
+  uint32_t                Irql;
   ns16550_context        *pns16550Context;
   setRegister_f           setReg;
@@ -258,6 +258,6 @@
 NS16550_STATIC int ns16550_negate_RTS(int minor)
 {
-  unsigned32              pNS16550;
-  unsigned32              Irql;
+  uint32_t                pNS16550;
+  uint32_t                Irql;
   ns16550_context        *pns16550Context;
   setRegister_f           setReg;
@@ -289,6 +289,6 @@
 NS16550_STATIC int ns16550_assert_DTR(int minor)
 {
-  unsigned32              pNS16550;
-  unsigned32              Irql;
+  uint32_t                pNS16550;
+  uint32_t                Irql;
   ns16550_context        *pns16550Context;
   setRegister_f           setReg;
@@ -315,6 +315,6 @@
 NS16550_STATIC int ns16550_negate_DTR(int minor)
 {
-  unsigned32              pNS16550;
-  unsigned32              Irql;
+  uint32_t                pNS16550;
+  uint32_t                Irql;
   ns16550_context        *pns16550Context;
   setRegister_f           setReg;
@@ -347,11 +347,11 @@
 )
 {
-  unsigned32              pNS16550;
-  unsigned32              ulBaudDivisor;
-  unsigned8               ucLineControl;
-  unsigned32              baud_requested;
+  uint32_t                pNS16550;
+  uint32_t                ulBaudDivisor;
+  uint8_t                 ucLineControl;
+  uint32_t                baud_requested;
   setRegister_f           setReg;
   getRegister_f           getReg;
-  unsigned32              Irql;
+  uint32_t                Irql;
 
   pNS16550 = Console_Port_Tbl[minor].ulCtrlPort1;
@@ -368,5 +368,5 @@
 
   ulBaudDivisor = NS16550_Baud(
-    (unsigned32) Console_Port_Tbl[minor].ulClock,
+    (uint32_t  ) Console_Port_Tbl[minor].ulClock,
     termios_baud_to_number(baud_requested)
   );
@@ -444,7 +444,7 @@
 )
 {
-  unsigned32              pNS16550;
-  volatile unsigned8      ucLineStatus; 
-  volatile unsigned8      ucInterruptId;
+  uint32_t                pNS16550;
+  volatile uint8_t        ucLineStatus; 
+  volatile uint8_t        ucInterruptId;
   unsigned char           cChar;
   getRegister_f           getReg;
@@ -540,5 +540,5 @@
 )
 {
-  unsigned32     pNS16550;
+  uint32_t       pNS16550;
   setRegister_f  setReg;
 
@@ -578,6 +578,6 @@
 )
 {
-  unsigned32     Irql;
-  unsigned32     pNS16550;
+  uint32_t       Irql;
+  uint32_t       pNS16550;
   setRegister_f  setReg;
 
@@ -650,5 +650,5 @@
 )
 {
-  unsigned32           pNS16550;
+  uint32_t             pNS16550;
   unsigned char        ucLineStatus;
   char                 cChar;
Index: c/src/libchip/serial/ns16550_p.h
===================================================================
--- c/src/libchip/serial/ns16550_p.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/ns16550_p.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -161,5 +161,5 @@
 typedef struct _ns16550_context
 {
-        unsigned8       ucModemCtrl;
+        uint8_t         ucModemCtrl;
 } ns16550_context;
 
Index: c/src/libchip/serial/serial.h
===================================================================
--- c/src/libchip/serial/serial.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/serial.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -23,9 +23,9 @@
  */
 
-typedef unsigned8 (*getRegister_f)(unsigned32 port, unsigned8 register);
+typedef uint8_t   (*getRegister_f)(uint32_t   port, uint8_t   register);
 typedef void      (*setRegister_f)(
-                            unsigned32 port, unsigned8 reg, unsigned8 value);
-typedef unsigned8 (*getData_f)(unsigned32 port);
-typedef void      (*setData_f)(unsigned32 port, unsigned8 value);
+                            uint32_t   port, uint8_t   reg, uint8_t   value);
+typedef uint8_t   (*getData_f)(uint32_t   port);
+typedef void      (*setData_f)(uint32_t   port, uint8_t   value);
 
 typedef struct _console_fns {
@@ -121,15 +121,15 @@
   boolean      (*deviceProbe)(int minor);
   console_flow  *pDeviceFlow;
-  unsigned32     ulMargin;
-  unsigned32     ulHysteresis;
+  uint32_t       ulMargin;
+  uint32_t       ulHysteresis;
   void          *pDeviceParams;
-  unsigned32     ulCtrlPort1;
-  unsigned32     ulCtrlPort2;
-  unsigned32     ulDataPort;
+  uint32_t       ulCtrlPort1;
+  uint32_t       ulCtrlPort2;
+  uint32_t       ulDataPort;
   getRegister_f  getRegister;
   setRegister_f  setRegister;
   getData_f      getData;
   setData_f      setData;
-  unsigned32     ulClock;
+  uint32_t       ulClock;
   unsigned int   ulIntVector;
 } console_tbl;
Index: c/src/libchip/serial/z85c30.c
===================================================================
--- c/src/libchip/serial/z85c30.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/z85c30.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -93,6 +93,6 @@
 )
 {
-  unsigned32      ulCtrlPort;
-  unsigned32      ulBaudDivisor;
+  uint32_t        ulCtrlPort;
+  uint32_t        ulBaudDivisor;
   setRegister_f   setReg;
 
@@ -138,6 +138,6 @@
 
   ulBaudDivisor = Z85C30_Baud( 
-    (unsigned32) Console_Port_Tbl[minor].ulClock,
-    (unsigned32) Console_Port_Tbl[minor].pDeviceParams
+    (uint32_t  ) Console_Port_Tbl[minor].ulClock,
+    (uint32_t  ) Console_Port_Tbl[minor].pDeviceParams
   );
 
@@ -254,6 +254,6 @@
 Z85C30_STATIC void z85c30_init(int minor)
 {
-  unsigned32       ulCtrlPort;
-  unsigned8        dummy;
+  uint32_t         ulCtrlPort;
+  uint8_t          dummy;
   z85c30_context  *pz85c30Context;
   setRegister_f    setReg;
@@ -431,9 +431,9 @@
 )
 {
-  unsigned32             ulCtrlPort;
-  unsigned32             ulBaudDivisor;
-  unsigned32             wr3;
-  unsigned32             wr4;
-  unsigned32             wr5;
+  uint32_t               ulCtrlPort;
+  uint32_t               ulBaudDivisor;
+  uint32_t               wr3;
+  uint32_t               wr4;
+  uint32_t               wr5;
   int                    baud_requested;
   setRegister_f          setReg;
@@ -452,6 +452,6 @@
 
   ulBaudDivisor = Z85C30_Baud( 
-    (unsigned32) Console_Port_Tbl[minor].ulClock,
-    (unsigned32) termios_baud_to_number( baud_requested )
+    (uint32_t  ) Console_Port_Tbl[minor].ulClock,
+    (uint32_t  ) termios_baud_to_number( baud_requested )
   );
 
@@ -533,9 +533,9 @@
 Z85C30_STATIC void z85c30_process(
   int        minor,
-  unsigned8  ucIntPend
-)
-{
-  unsigned32          ulCtrlPort;
-  volatile unsigned8  z85c30_status;
+  uint8_t    ucIntPend
+)
+{
+  uint32_t            ulCtrlPort;
+  volatile uint8_t    z85c30_status;
   unsigned char       cChar;
   setRegister_f       setReg;
@@ -642,7 +642,7 @@
 {
   int                 minor;
-  unsigned32          ulCtrlPort;
-  volatile unsigned8  ucIntPend;
-  volatile unsigned8  ucIntPendPort;
+  uint32_t            ulCtrlPort;
+  volatile uint8_t    ucIntPend;
+  volatile uint8_t    ucIntPendPort;
   getRegister_f       getReg;
 
@@ -685,5 +685,5 @@
 )
 {
-  unsigned32     ulCtrlPort;
+  uint32_t       ulCtrlPort;
   setRegister_f  setReg;
 
@@ -704,6 +704,6 @@
 )
 {
-  unsigned32     ulCtrlPort1;
-  unsigned32     ulCtrlPort2;
+  uint32_t       ulCtrlPort1;
+  uint32_t       ulCtrlPort2;
   setRegister_f  setReg;
 
@@ -749,6 +749,6 @@
   int   len)
 {
-  unsigned32     Irql;
-  unsigned32     ulCtrlPort;
+  uint32_t       Irql;
+  uint32_t       ulCtrlPort;
   setRegister_f  setReg;
 
@@ -792,6 +792,6 @@
 )
 {
-  volatile unsigned8  z85c30_status;
-  unsigned32          ulCtrlPort;
+  volatile uint8_t    z85c30_status;
+  uint32_t            ulCtrlPort;
   getRegister_f       getReg;
 
@@ -853,6 +853,6 @@
 )
 {
-  volatile unsigned8 z85c30_status;
-  unsigned32         ulCtrlPort;
+  volatile uint8_t   z85c30_status;
+  uint32_t           ulCtrlPort;
   getRegister_f      getReg;
   setRegister_f      setReg;
Index: c/src/libchip/serial/z85c30.h
===================================================================
--- c/src/libchip/serial/z85c30.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/z85c30.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -51,22 +51,22 @@
  */
 
-unsigned8 z85c30_get_register(   /* registers are byte-wide */
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint8_t   z85c30_get_register(   /* registers are byte-wide */
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 );
 
 void z85c30_set_register(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 );
 
-unsigned8 z85c30_get_data(
-  unsigned32  ulDataPort
+uint8_t   z85c30_get_data(
+  uint32_t    ulDataPort
 );
 
 void z85c30_set_data(
-  unsigned32  ulDataPort,
-  unsigned8   ucData
+  uint32_t    ulDataPort,
+  uint8_t     ucData
 );
 
Index: c/src/libchip/serial/z85c30_p.h
===================================================================
--- c/src/libchip/serial/z85c30_p.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/z85c30_p.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -311,5 +311,5 @@
 typedef struct _z85c30_context
 {
-  unsigned8 ucModemCtrl;
+  uint8_t   ucModemCtrl;
 } z85c30_context;
 
Index: c/src/libchip/serial/z85c30_reg.c
===================================================================
--- c/src/libchip/serial/z85c30_reg.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/serial/z85c30_reg.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -20,5 +20,5 @@
 #define _Z85C30_MULTIPLIER 1
 #define _Z85C30_NAME(_X) _X
-#define _Z85C30_TYPE unsigned8
+#define _Z85C30_TYPE uint8_t  
 #endif
 
@@ -27,11 +27,11 @@
  */
 
-unsigned8 _Z85C30_NAME(z85c30_get_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum
+uint8_t   _Z85C30_NAME(z85c30_get_register)(
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum
 )
 {
   _Z85C30_TYPE          *port;
-  unsigned8              data;
+  uint8_t                data;
   rtems_interrupt_level  level;
 
@@ -54,7 +54,7 @@
 
 void _Z85C30_NAME(z85c30_set_register)(
-  unsigned32  ulCtrlPort,
-  unsigned8   ucRegNum,
-  unsigned8   ucData
+  uint32_t    ulCtrlPort,
+  uint8_t     ucRegNum,
+  uint8_t     ucData
 )
 {
Index: c/src/libchip/shmdr/addlq.c
===================================================================
--- c/src/libchip/shmdr/addlq.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/addlq.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -27,5 +27,5 @@
 )
 {
-  rtems_unsigned32 index;
+  uint32_t   index;
 
   ecb->next  = Shm_Locked_queue_End_of_list;
Index: c/src/libchip/shmdr/cnvpkt.c
===================================================================
--- c/src/libchip/shmdr/cnvpkt.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/cnvpkt.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -31,7 +31,7 @@
 )
 {
-  rtems_unsigned32 *pkt, i;
+  uint32_t   *pkt, i;
 
-  pkt = (rtems_unsigned32 *) packet;
+  pkt = (uint32_t   *) packet;
   for ( i=RTEMS_MINIMUN_HETERO_CONVERSION ; i ; i--, pkt++ )
     *pkt = CPU_swap_u32( *pkt );
Index: c/src/libchip/shmdr/dump.c
===================================================================
--- c/src/libchip/shmdr/dump.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/dump.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -25,7 +25,7 @@
 Shm_Print_statistics(void)
 {
-  rtems_unsigned32  ticks;
-  rtems_unsigned32  ticks_per_second;
-  rtems_unsigned32  seconds;
+  uint32_t    ticks;
+  uint32_t    ticks_per_second;
+  uint32_t    seconds;
   int               packets_per_second;
 
Index: c/src/libchip/shmdr/fatal.c
===================================================================
--- c/src/libchip/shmdr/fatal.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/fatal.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -24,5 +24,5 @@
   Internal_errors_Source  source,
   boolean                 is_internal,
-  rtems_unsigned32        error
+  uint32_t          error
 )
 {
Index: c/src/libchip/shmdr/getlq.c
===================================================================
--- c/src/libchip/shmdr/getlq.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/getlq.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -29,5 +29,5 @@
 {
   Shm_Envelope_control *tmp_ecb;
-  rtems_unsigned32 tmpfront;
+  uint32_t   tmpfront;
 
   tmp_ecb = NULL;
Index: c/src/libchip/shmdr/init.c
===================================================================
--- c/src/libchip/shmdr/init.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/init.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -37,10 +37,10 @@
 
 {
-  rtems_unsigned32         i, all_initialized;
-  rtems_unsigned32         interrupt_cause, interrupt_value;
+  uint32_t           i, all_initialized;
+  uint32_t           interrupt_cause, interrupt_value;
   void                    *interrupt_address;
   Shm_Node_status_control *nscb;
-  rtems_unsigned32         extension_id;    /* for installation of MPCI_Fatal */
-  rtems_unsigned32         remaining_memory;
+  uint32_t           extension_id;    /* for installation of MPCI_Fatal */
+  uint32_t           remaining_memory;
 /* XXX these should use "public" methods to set their values.... */
   rtems_configuration_table   *configuration = _Configuration_Table;
@@ -123,5 +123,5 @@
 
   interrupt_address =
-    (void *) Shm_Convert( (rtems_unsigned32)Shm_Configuration->Intr.address );
+    (void *) Shm_Convert( (uint32_t  )Shm_Configuration->Intr.address );
   interrupt_value   = Shm_Convert( Shm_Configuration->Intr.value );
   interrupt_cause   = Shm_Convert( Shm_Configuration->Intr.length );
@@ -173,5 +173,5 @@
      */
 
-    Shm_Local_node_status->int_address = (rtems_unsigned32) interrupt_address;
+    Shm_Local_node_status->int_address = (uint32_t  ) interrupt_address;
     Shm_Local_node_status->int_value   = interrupt_value;
     Shm_Local_node_status->int_length  = interrupt_cause;
@@ -221,5 +221,5 @@
 
         Shm_Local_node_status->int_address =
-          (rtems_unsigned32) interrupt_address;
+          (uint32_t  ) interrupt_address;
         Shm_Local_node_status->int_value   = interrupt_value;
         Shm_Local_node_status->int_length  = interrupt_cause;
Index: c/src/libchip/shmdr/initlq.c
===================================================================
--- c/src/libchip/shmdr/initlq.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/initlq.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -25,5 +25,5 @@
 void Shm_Locked_queue_Initialize(
   Shm_Locked_queue_Control *lq_cb,
-  rtems_unsigned32 owner
+  uint32_t   owner
 )
 {
Index: c/src/libchip/shmdr/intr.c
===================================================================
--- c/src/libchip/shmdr/intr.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/intr.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -27,12 +27,12 @@
 
 void Shm_Cause_interrupt(
-  rtems_unsigned32 node
+  uint32_t   node
 )
 {
   Shm_Interrupt_information *intr;
-  rtems_unsigned8  *u8;
-  rtems_unsigned16 *u16;
-  rtems_unsigned32 *u32;
-  rtems_unsigned32  value;
+  uint8_t    *u8;
+  uint16_t   *u16;
+  uint32_t   *u32;
+  uint32_t    value;
 
   intr = &Shm_Interrupt_table[node];
@@ -43,14 +43,14 @@
        break;
     case BYTE:
-      u8   = (rtems_unsigned8 *)intr->address;
-      *u8  = (rtems_unsigned8) value;
+      u8   = (uint8_t   *)intr->address;
+      *u8  = (uint8_t  ) value;
       break;
     case WORD:
-      u16   = (rtems_unsigned16 *)intr->address;
-      *u16  = (rtems_unsigned16) value;
+      u16   = (uint16_t   *)intr->address;
+      *u16  = (uint16_t  ) value;
       break;
     case LONG:
-      u32   = (rtems_unsigned32 *)intr->address;
-      *u32  = (rtems_unsigned32) value;
+      u32   = (uint32_t   *)intr->address;
+      *u32  = (uint32_t  ) value;
       break;
   }
Index: c/src/libchip/shmdr/poll.c
===================================================================
--- c/src/libchip/shmdr/poll.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/poll.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -27,5 +27,5 @@
 void Shm_Poll()
 {
-  rtems_unsigned32 tmpfront;
+  uint32_t   tmpfront;
   rtems_libio_ioctl_args_t args;
 
Index: c/src/libchip/shmdr/send.c
===================================================================
--- c/src/libchip/shmdr/send.c	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/send.c	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -26,14 +26,14 @@
 
 struct pkt_cpy {
-  rtems_unsigned32 packet[MAX_PACKET_SIZE/4];
+  uint32_t   packet[MAX_PACKET_SIZE/4];
 };
 
 rtems_mpci_entry Shm_Send_packet(
-  rtems_unsigned32 node,
+  uint32_t   node,
   rtems_packet_prefix *packet
 )
 {
   Shm_Envelope_control *ecb, *tmp_ecb;
-  rtems_unsigned32 nnum;
+  uint32_t   nnum;
 
   ecb = Shm_Packet_prefix_to_envelope_control_pointer( packet );
Index: c/src/libchip/shmdr/shm_driver.h
===================================================================
--- c/src/libchip/shmdr/shm_driver.h	(revision 83c5fc1bb9b45c22e428e1f7642b5a67cbf44b98)
+++ c/src/libchip/shmdr/shm_driver.h	(revision ee4f57d9a6c032da422c6b9b84761dbb30cc2fd8)
@@ -85,5 +85,5 @@
  *  comply with the restrictive placement of lock bit by this
  *  instruction.  The lock bit is the most significant bit in a
  *  big-endian rtems_unsigned32.  On other processors, the lock is
  *  typically implemented via an atomic swap or atomic modify
  *  bits type instruction.
@@ -255,5 +255,5 @@
 
 #define Shm_Packet_prefix_to_envelope_control_pointer( pkt )   \
-   ((Shm_Envelope_control *)((rtems_unsigned8 *)(pkt) - \
+   ((Shm_Envelope_control *)((uint8_t   *)(pkt) - \
    (sizeof(Shm_Envelope_preamble) + SHM_ENVELOPE_PREFIX_OVERHEAD)))
 
@@ -265,6 +265,6 @@
 /* volatile types */
 
-typedef volatile rtems_unsigned8  vol_u8;
-typedef volatile rtems_unsigned32 vol_u32;
+typedef volatile uint8_t    vol_u8;
+typedef volatile uint32_t   vol_u32;
 
 /* shm control information */
@@ -397,5 +397,5 @@
  *               address may be specific to this node.
  *  length     - The length of the shared memory in bytes.
- *  format     - The natural format for rtems_unsigned32's in the
+ *  format     - The natural format for uint32_t  's in the
  *               shared memory.  Valid values are currently
  *               only SHM_LITTLE and SHM_BIG.
@@ -426,5 +426,5 @@
   vol_u32          (*convert)();/* neutral conversion routine */
   vol_u32            poll_intr;/* POLLED or INTR driven mode  */
-  void             (*cause_intr)( rtems_unsigned32 );
+  void             (*cause_intr)( uint32_t   );
   Shm_Interrupt_information   Intr;     /* cause intr information      */
 };
@@ -447,22 +447,22 @@
 SHM_EXTERN rtems_configuration_table    *Shm_RTEMS_Configuration;
 SHM_EXTERN rtems_multiprocessing_table  *Shm_RTEMS_MP_Configuration;
-SHM_EXTERN rtems_unsigned32              Shm_Receive_message_count;
-SHM_EXTERN rtems_unsigned32              Shm_Null_message_count;
-SHM_EXTERN rtems_unsigned32              Shm_Interrupt_count;
-SHM_EXTERN rtems_unsigned32              Shm_Local_node;
+SHM_EXTERN uint32_t                Shm_Receive_message_count;
+SHM_EXTERN uint32_t                Shm_Null_message_count;
+SHM_EXTERN uint32_t                Shm_Interrupt_count;
+SHM_EXTERN uint32_t                Shm_Local_node;
 SHM_EXTERN Shm_Locked_queue_Control      *Shm_Local_receive_queue;
 SHM_EXTERN Shm_Node_status_control       *Shm_Local_node_status;
-SHM_EXTERN rtems_unsigned32              Shm_isrstat;
+SHM_EXTERN uint32_t                Shm_isrstat;
                                                      /* reported by shmdr */
 
-SHM_EXTERN rtems_unsigned32 Shm_Pending_initialization;
-SHM_EXTERN rtems_unsigned32 Shm_Initialization_complete;
-SHM_EXTERN rtems_unsigned32 Shm_Active_node;
-
-SHM_EXTERN rtems_unsigned32 Shm_Maximum_nodes;
-SHM_EXTERN rtems_unsigned32 Shm_Maximum_envelopes;
-
-SHM_EXTERN rtems_unsigned32 Shm_Locked_queue_End_of_list;
-SHM_EXTERN rtems_unsigned32 Shm_Locked_queue_Not_on_list;
+SHM_EXTERN uint32_t   Shm_Pending_initialization;
+SHM_EXTERN uint32_t   Shm_Initialization_complete;
+SHM_EXTERN uint32_t   Shm_Active_node;
+
+SHM_EXTERN uint32_t   Shm_Maximum_nodes;
+SHM_EXTERN uint32_t   Shm_Maximum_envelopes;
+
+SHM_EXTERN uint32_t   Shm_Locked_queue_End_of_list;
+SHM_EXTERN uint32_t   Shm_Locked_queue_Not_on_list;
 
 /* functions */
@@ -473,5 +473,5 @@
 Shm_Envelope_control *Shm_Locked_queue_Get( Shm_Locked_queue_Control * );
 void           Shm_Locked_queue_Initialize(
-                  Shm_Locked_queue_Control *, rtems_unsigned32 );
+                  Shm_Locked_queue_Control *, uint32_t   );
             /* Shm_Initialize_lock is CPU dependent */
             /* Shm_Lock is CPU dependent */
@@ -481,6 +481,6 @@
 void           Init_env_pool();
 void           Shm_Print_statistics( void );
-void           MPCI_Fatal( Internal_errors_Source, boolean, rtems_unsigned32 );
-rtems_task     Shm_Cause_interrupt( rtems_unsigned32 );
+void           MPCI_Fatal( Internal_errors_Source, boolean, uint32_t   );
+rtems_task     Shm_Cause_interrupt( uint32_t   );
 void           Shm_Poll();
 void           Shm_setclockvec();
@@ -491,5 +491,5 @@
 /* target specific routines */
 void          *Shm_Convert_address( void * );
-void           Shm_Get_configuration( rtems_unsigned32, shm_config_table ** );
+void           Shm_Get_configuration( uint32_t  , shm_config_table ** );
 void           Shm_isr();
 void           Shm_setvec( void );
@@ -515,5 +515,5 @@
 
 rtems_mpci_entry Shm_Send_packet(
-  rtems_unsigned32,
+  uint32_t  ,
   rtems_packet_prefix *
 );
@@ -85,5 +85,5 @@
  *  comply with the restrictive placement of lock bit by this
  *  instruction.  The lock bit is the most significant bit in a
- *  big-endian rtems_unsigned32.  On other processors, the lock is
+ *  big-endian uint32_t  .  On other processors, the lock is
  *  typically implemented via an atomic swap or atomic modify
  *  bits type instruction.
